==> pagseguro_sdk-0.0.4.tar.gz: example/lib/main.dart <==
import 'package:flutter/material.dart';
import 'dart:async';

import 'package:flutter/services.dart';
import 'package:pagseguro_sdk/pagseguro_sdk.dart';

void main() {
  runApp(MyApp());
}

class MyApp extends StatefulWidget {
  @override
  _MyAppState createState() => _MyAppState();
}

class _MyAppState extends State<MyApp> {
  String _platformVersion = 'Unknown';

  @override
  void initState() {
    super.initState();
    initPlatformState();
  }

  // Platform messages are asynchronous, so we initialize in an async method.
  Future<void> initPlatformState() async {
    String platformVersion;
    // Platform messages may fail, so we use a try/catch PlatformException.
    try {

      var plug = PagseguroSdk();

      platformVersion = await plug.platformVersion;
      print('ahoy' + platformVersion);

      await plug.initialize(appVersion: "1.0.0", appName: "teste", activationCode: "403938");

      print('subscribe to events');

      plug.subscribeToEvents((event){
        print('ahoy $event');
      });

      print('make the payment');

      var a = await plug.getInstallments(amount: 100.0);

      print('installments $a');

      await plug.startPayment(amount: 100.0, installments: 1, type: 'C');


    } on PlatformException {
      platformVersion = 'Failed to get platform version.';
    }

    // If the widget was removed from the tree while the asynchronous platform
    // message was in flight, we want to discard the reply rather than calling
    // setState to update our non-existent appearance.
    if (!mounted) return;

    setState(() {
      _platformVersion = platformVersion;
    });
  }

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      home: Scaffold(
        appBar: AppBar(
          title: const Text('Plugin example app'),
        ),
        body: Center(
          child: Text('Running on: $_platformVersion\n'),
        ),
      ),
    );
  }
}

==> pagseguro_sdk-0.0.19.tar.gz: example/lib/main.dart <==
import 'package:flutter/material.dart';
import 'dart:async';

import 'package:flutter/services.dart';
import 'package:pagseguro_sdk/pagseguro_sdk.dart';

void main() {
  runApp(MyApp());
}

class MyApp extends StatefulWidget {
  @override
  _MyAppState createState() => _MyAppState();
}

class _MyAppState extends State<MyApp> {
  String _platformVersion = 'Unknown';

  @override
  void initState() {
    super.initState();
    initPlatformState();
  }

  // Platform messages are asynchronous, so we initialize in an async method.
  Future<void> initPlatformState() async {
    String platformVersion;
    // Platform messages may fail, so we use a try/catch PlatformException.
    try {

      var plug = PagseguroSdk();

      platformVersion = await plug.platformVersion;
      print('ahoy' + platformVersion);

      await plug.initialize(appVersion: "1.0.0", appName: "teste", activationCode: "403938");

      print('subscribe to events');

      plug.subscribeToEvents().listen((event) {
        print('event: ${event.message}');
      });

      print('make the payment');

      var a = await plug.getInstallments(amount: 100.0);

      print('installments $a');

      await plug.startPayment(amount: 100.0, installments: 1, type: 'C');


    } on PlatformException {
      platformVersion = 'Failed to get platform version.';
    }

    // If the widget was removed from the tree while the asynchronous platform
    // message was in flight, we want to discard the reply rather than calling
    // setState to update our non-existent appearance.
    if (!mounted) return;

    setState(() {
      _platformVersion = platformVersion;
    });
  }

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      home: Scaffold(
        appBar: AppBar(
          title: const Text('Plugin example app'),
        ),
        body: Center(
          child: Text('Running on: $_platformVersion\n'),
        ),
      ),
    );
  }
}
